@@ -1,7 +1,7 @@
 package Pod::Weaver::Plugin::Regexp::Pattern;
 
 our $DATE = '2018-09-10'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use Moose;
@@ -120,7 +120,7 @@ sub _process_module {
                 for my $eg (@eg) {
                     push @pod, " # $eg->{summary}\n" if defined $eg->{summary};
 
-                    push @pod, " ", dmp($eg->{str}), " =~ re(", dmp("$rp_package\::$patname"), "); ";
+                    push @pod, " ", dmp($eg->{str}), " =~ re(", dmp("$rp_package\::$patname"), ($eg->{gen_args} ? ", ".dmp($eg->{gen_args}) : ""), "); ";
                     if (ref $eg->{matches} eq 'ARRAY') {
                         if (@{ $eg->{matches} }) {
                             push @pod, "# matches, ",
@@ -196,7 +196,7 @@ Pod::Weaver::Plugin::Regexp::Pattern - Plugin to use when building Regexp::Patte
 
 =head1 VERSION
 
-This document describes version 0.002 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2018-09-10.
+This document describes version 0.003 of Pod::Weaver::Plugin::Regexp::Pattern (from Perl distribution Pod-Weaver-Plugin-Regexp-Pattern), released on 2018-09-10.
 
 =head1 SYNOPSIS
 
